HTTP and Pagination
===================

REST client helpers, pagination primitives, transport abstractions, and retry
support.

.. autosummary::
   :toctree: generated

   etlplus.api.auth
   etlplus.api.config
   etlplus.api.endpoint_client
   etlplus.api.enums
   etlplus.api.pagination.client
   etlplus.api.pagination.config
   etlplus.api.pagination.paginator
   etlplus.api.rate_limiting.rate_limiter
   etlplus.api.retry_manager
   etlplus.api.transport
   etlplus.api.types
   etlplus.api.utils
